pub fn render_buildfix_section(summary: &BuildfixSummary) -> StringExpand description
Render a buildfix summary as a markdown section for the PR comment.
pub fn render_buildfix_section(summary: &BuildfixSummary) -> StringRender a buildfix summary as a markdown section for the PR comment.