pub fn render_trend_section(trend: &TrendDelta) -> StringExpand description
Render a trend delta as a markdown section for the PR comment.
pub fn render_trend_section(trend: &TrendDelta) -> StringRender a trend delta as a markdown section for the PR comment.